Learn R Programming

nodbi (version 0.15.0)

docdb_list: List containers in database

Description

List containers in database

Usage

docdb_list(src, ...)

Value

Vector of names of containers that can be used as parameter key with other functions such as docdb_create().

Arguments

src

Source object, result of call to any of functions src_mongo(), src_sqlite(), src_duckdb(), src_postgres(), src_mariadb(), src_elastic() or src_couchdb()

...

Passed to function DBI::dbListTables()

Examples

Run this code
if (FALSE) {
src <- src_sqlite()
docdb_create(src, "iris", iris)
docdb_list(src)
}

Run the code above in your browser using DataLab