Vector of names of containers that can be
used as parameter key with other functions such as
docdb_create().
Arguments
src
Source object, result of call to any of functions
src_mongo(), src_sqlite(), src_duckdb(), src_postgres(),
src_mariadb(), src_elastic() or src_couchdb()